PaintContext

Struct PaintContext 

pub struct PaintContext { /* private fields */ }
The paint context used for custom 2D drawing

PaintContext wraps a RecordingContext to record draw commands, while providing a Canvas-like API for convenience.

Implementations

Source

impl PaintContext

pub fn new(width: f32, height: f32) -> Self

Create a new paint context with the given viewport size

pub fn from_size(size: Size) -> Self

Create from a Size

pub fn commands(&self) -> &[DrawCommand]

Get all recorded commands

pub fn take_commands(&mut self) -> Vec<DrawCommand>

Take ownership of recorded commands

pub fn fill_rect_xywh( &mut self, x: f32, y: f32, width: f32, height: f32, brush: impl Into<Brush>, )

Fill a rectangle at (x, y) with width/height and a brush

pub fn stroke_rect_xywh( &mut self, x: f32, y: f32, width: f32, height: f32, stroke: &Stroke, brush: impl Into<Brush>, )

Stroke a rectangle at (x, y) with width/height

pub fn fill_rounded_rect_xywh( &mut self, x: f32, y: f32, width: f32, height: f32, radius: f32, brush: impl Into<Brush>, )

Fill a rounded rectangle

pub fn fill_circle_xyr( &mut self, cx: f32, cy: f32, radius: f32, brush: impl Into<Brush>, )

Fill a circle at (cx, cy) with radius

pub fn stroke_circle_xyr( &mut self, cx: f32, cy: f32, radius: f32, stroke: &Stroke, brush: impl Into<Brush>, )

Stroke a circle at (cx, cy) with radius

pub fn draw_text_simple( &mut self, text: impl Into<String>, x: f32, y: f32, size: f32, color: Color, )

Draw text at (x, y) with size and color

pub fn translate(&mut self, x: f32, y: f32)

Push a translation transform

pub fn scale(&mut self, sx: f32, sy: f32)

Push a scale transform

pub fn rotate(&mut self, angle: f32)

Push a rotation transform (angle in radians)