pub struct PaintContext { /* private fields */ }Expand description
The paint context used for custom 2D drawing
PaintContext wraps a RecordingContext to record draw commands, while providing a Canvas-like API for convenience.
Implementations
Sourceimpl PaintContext
impl PaintContext
Sourcepub fn new(width: f32, height: f32) -> Self
pub fn new(width: f32, height: f32) -> Self
Create a new paint context with the given viewport size
Sourcepub fn commands(&self) -> &[DrawCommand]
pub fn commands(&self) -> &[DrawCommand]
Get all recorded commands
Sourcepub fn take_commands(&mut self) -> Vec<DrawCommand>
pub fn take_commands(&mut self) -> Vec<DrawCommand>
Take ownership of recorded commands
Sourcepub fn fill_rect_xywh(
&mut self,
x: f32,
y: f32,
width: f32,
height: f32,
brush: impl Into<Brush>,
)
pub fn fill_rect_xywh( &mut self, x: f32, y: f32, width: f32, height: f32, brush: impl Into<Brush>, )
Fill a rectangle at (x, y) with width/height and a brush
Sourcepub fn stroke_rect_xywh(
&mut self,
x: f32,
y: f32,
width: f32,
height: f32,
stroke: &Stroke,
brush: impl Into<Brush>,
)
pub fn stroke_rect_xywh( &mut self, x: f32, y: f32, width: f32, height: f32, stroke: &Stroke, brush: impl Into<Brush>, )
Stroke a rectangle at (x, y) with width/height
Sourcepub fn fill_rounded_rect_xywh(
&mut self,
x: f32,
y: f32,
width: f32,
height: f32,
radius: f32,
brush: impl Into<Brush>,
)
pub fn fill_rounded_rect_xywh( &mut self, x: f32, y: f32, width: f32, height: f32, radius: f32, brush: impl Into<Brush>, )
Fill a rounded rectangle
Sourcepub fn fill_circle_xyr(
&mut self,
cx: f32,
cy: f32,
radius: f32,
brush: impl Into<Brush>,
)
pub fn fill_circle_xyr( &mut self, cx: f32, cy: f32, radius: f32, brush: impl Into<Brush>, )
Fill a circle at (cx, cy) with radius
Sourcepub fn stroke_circle_xyr(
&mut self,
cx: f32,
cy: f32,
radius: f32,
stroke: &Stroke,
brush: impl Into<Brush>,
)
pub fn stroke_circle_xyr( &mut self, cx: f32, cy: f32, radius: f32, stroke: &Stroke, brush: impl Into<Brush>, )
Stroke a circle at (cx, cy) with radius